Apps (`sigpy.app`)
==================

.. automodule::
   sigpy.app

The App Class
-------------
.. autosummary::
   :toctree: generated
   :nosignatures:
   
   sigpy.app.App

Apps
----
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.app.MaxEig
   sigpy.app.LinearLeastSquares
